summaryrefslogtreecommitdiff
path: root/src/mongo/db/pipeline/document_source.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/pipeline/document_source.h')
-rw-r--r--src/mongo/db/pipeline/document_source.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/mongo/db/pipeline/document_source.h b/src/mongo/db/pipeline/document_source.h
index 5e8244e7984..49689de85dd 100644
--- a/src/mongo/db/pipeline/document_source.h
+++ b/src/mongo/db/pipeline/document_source.h
@@ -461,10 +461,11 @@ public:
/**
* Returns true if it would be correct to execute this stage in parallel across the shards in
* cases where the final stage is an $out. For example, a $group stage which is just merging the
* groups from the shards can be run in parallel since it will preserve the shard key.
*/
- virtual bool canRunInParallelBeforeOut(
+ virtual bool canRunInParallelBeforeWriteStage(
const std::set<std::string>& nameOfShardKeyFieldsUponEntryToStage) const {
return false;
}
@@ -461,10 +461,11 @@ public:
/**
* Returns true if it would be correct to execute this stage in parallel across the shards in
- * cases where the final stage is an $out. For example, a $group stage which is just merging the
- * groups from the shards can be run in parallel since it will preserve the shard key.
+ * cases where the final stage is a stage which can perform a write operation, such as $merge.
+ * For example, a $group stage which is just merging the groups from the shards can be run in
+ * parallel since it will preserve the shard key.
*/